@@ -6,7 +6,7 @@
 #' Calculate parametric, non-parametric, robust, and Bayes Factor pairwise
 #' comparisons between group levels with corrections for multiple testing.
 #'
-#' @inheritParams ipmisc::long_to_wide_converter
+#' @inheritParams statsExpressions::long_to_wide_converter
 #' @param type Type of statistic expected (`"parametric"` or `"nonparametric"`
 #'   or `"robust"` or `"bayes"`).Corresponding abbreviations are also accepted:
 #'   `"p"` (for parametric), `"np"` (nonparametric), `"r"` (robust), or
@@ -57,14 +57,14 @@
 #'   \item *Bayes Factor* : [BayesFactor::ttestBF()]
 #'   }
 #'
-#' @importFrom dplyr select rename mutate everything mutate_if across starts_with
-#' @importFrom dplyr bind_cols matches rowwise ungroup
+#' @import dplyr
+#' @import rlang
+#' @import statsExpressions
+#'
 #' @importFrom stats p.adjust pairwise.t.test na.omit aov
 #' @importFrom WRS2 lincon rmmcp
 #' @importFrom PMCMRplus durbinAllPairsTest kwAllPairsDunnTest gamesHowellTest
-#' @importFrom rlang !!! ensym exec call2 new_formula
 #' @importFrom purrr map2 map_dfr
-#' @importFrom ipmisc stats_type_switch format_num long_to_wide_converter
 #' @importFrom parameters model_parameters standardize_names
 #' @importFrom insight format_value
 #'
@@ -73,6 +73,7 @@
 #' # for reproducibility
 #' set.seed(123)
 #' library(pairwiseComparisons)
+#' library(statsExpressions) # for data
 #'
 #' # show all columns and make the column titles bold
 #' # as a user, you don't need to do this; this is just for the package website
@@ -193,17 +194,16 @@ pairwise_comparisons <- function(data,
                                  k = 2L,
                                  ...) {
   # standardize stats type
-  type <- ipmisc::stats_type_switch(type)
+  type <- stats_type_switch(type)
 
   # ensure the arguments work quoted or unquoted
-  c(x, y) %<-% c(rlang::ensym(x), rlang::ensym(y))
+  c(x, y) %<-% c(ensym(x), ensym(y))
 
-  # ---------------------------- data cleanup -------------------------------
+  # dataframe -------------------------------
 
-  # creating a dataframe (it's important for the data to be sorted by `x`)
-  df_int <-
-    ipmisc::long_to_wide_converter(
-      data = data,
+  # cleaning up dataframe
+  data %<>%
+    long_to_wide_converter(
       x = {{ x }},
       y = {{ y }},
       subject.id = {{ subject.id }},
@@ -212,26 +212,26 @@ pairwise_comparisons <- function(data,
     )
 
   # for some tests, it's better to have these as vectors
-  x_vec <- df_int %>% dplyr::pull({{ x }})
-  y_vec <- df_int %>% dplyr::pull({{ y }})
-  g_vec <- df_int$rowid
+  x_vec <- data %>% pull({{ x }})
+  y_vec <- data %>% pull({{ y }})
+  g_vec <- data$rowid
   .f.args <- list(...)
 
-  # ---------------------------- parametric ---------------------------------
+  # parametric ---------------------------------
 
   if (type %in% c("parametric", "bayes")) {
-    if (isTRUE(var.equal) || isTRUE(paired)) {
+    if (var.equal || paired) {
       c(.f, test.details) %<-% c(stats::pairwise.t.test, "Student's t-test")
     } else {
       c(.f, test.details) %<-% c(PMCMRplus::gamesHowellTest, "Games-Howell test")
     }
   }
 
-  # ---------------------------- nonparametric ----------------------------
+  # nonparametric ----------------------------
 
   if (type == "nonparametric") {
-    if (isFALSE(paired)) c(.f, test.details) %<-% c(PMCMRplus::kwAllPairsDunnTest, "Dunn test")
-    if (isTRUE(paired)) c(.f, test.details) %<-% c(PMCMRplus::durbinAllPairsTest, "Durbin-Conover test")
+    if (!paired) c(.f, test.details) %<-% c(PMCMRplus::kwAllPairsDunnTest, "Dunn test")
+    if (paired) c(.f, test.details) %<-% c(PMCMRplus::durbinAllPairsTest, "Durbin-Conover test")
 
     # `exec` fails otherwise for `pairwise.t.test` because `y` is passed to `t.test`
     .f.args <- list(y = y_vec, ...)
@@ -239,9 +239,9 @@ pairwise_comparisons <- function(data,
 
   # running the appropriate test
   if (type != "robust") {
-    df <- suppressWarnings(rlang::exec(
+    df <- suppressWarnings(exec(
       .fn = .f,
-      # Dunn, Games-Howell, Student test
+      # Dunn, Games-Howell, Student's t-test
       x = y_vec,
       g = x_vec,
       # Durbin-Conover test
@@ -250,36 +250,35 @@ pairwise_comparisons <- function(data,
       # Student
       paired = paired,
       # common
-      na.action = na.omit,
       p.adjust.method = "none",
       # problematic for other methods
       !!!.f.args
     )) %>%
       tidy_model_parameters(.) %>%
-      dplyr::rename(group2 = group1, group1 = group2)
+      rename(group2 = group1, group1 = group2)
   }
 
-  # ---------------------------- robust ----------------------------------
+  # robust ----------------------------------
 
   # extracting the robust pairwise comparisons
   if (type == "robust") {
-    if (isFALSE(paired)) {
+    if (!paired) {
       c(.ns, .fn) %<-% c("WRS2", "lincon")
-      .f.args <- list(formula = rlang::new_formula(y, x), data = df_int)
+      .f.args <- list(formula = new_formula(y, x), data = data, method = "none")
     } else {
       c(.ns, .fn) %<-% c("WRS2", "rmmcp")
       .f.args <- list(y = quote(y_vec), groups = quote(x_vec), blocks = quote(g_vec))
     }
 
     # cleaning the raw object and getting it in the right format
-    df <- eval(rlang::call2(.ns = .ns, .fn = .fn, tr = tr, !!!.f.args)) %>%
+    df <- eval(call2(.ns = .ns, .fn = .fn, tr = tr, !!!.f.args)) %>%
       tidy_model_parameters(.)
 
     # test details
     test.details <- "Yuen's trimmed means test"
   }
 
-  # ---------------------------- bayes factor --------------------------------
+  # Bayesian --------------------------------
 
   if (type == "bayes") {
     # combining results into a single dataframe and returning it
@@ -288,54 +287,140 @@ pairwise_comparisons <- function(data,
       .x = purrr::map2(
         .x = as.character(df$group1),
         .y = as.character(df$group2),
-        .f = function(a, b) droplevels(dplyr::filter(df_int, {{ x }} %in% c(a, b)))
+        .f = function(a, b) droplevels(filter(data, {{ x }} %in% c(a, b)))
       ),
       # internal function to carry out BF t-test
-      .f = ~ bf_ttest(
+      .f = ~ two_sample_test(
         data = .x,
         x = {{ x }},
         y = {{ y }},
         paired = paired,
-        bf.prior = bf.prior
+        bf.prior = bf.prior,
+        type = "bayes"
       )
     ) %>%
-      dplyr::rowwise() %>%
-      dplyr::mutate(label = paste0("list(~log[e](BF['01'])==", format_value(-log_e_bf10, k), ")")) %>%
-      dplyr::ungroup() %>%
-      dplyr::mutate(test.details = "Student's t-test")
+      filter(term == "Difference") %>%
+      rowwise() %>%
+      mutate(label = paste0("list(~log[e](BF['01'])==", format_value(-log_e_bf10, k), ")")) %>%
+      ungroup() %>%
+      mutate(test.details = "Student's t-test")
 
     # combine it with the other details
-    df <- dplyr::bind_cols(dplyr::select(df, group1, group2), df_tidy)
+    df <- bind_cols(select(df, group1, group2), df_tidy)
   }
 
-  # ---------------------------- cleanup ----------------------------------
+  # cleanup ----------------------------------
 
   # final cleanup for p-value labels
   df %<>%
-    dplyr::mutate_if(.predicate = is.factor, .funs = ~ as.character(.)) %>%
-    dplyr::arrange(group1, group2) %>%
-    dplyr::select(group1, group2, dplyr::everything())
+    mutate_if(.predicate = is.factor, .funs = ~ as.character(.)) %>%
+    arrange(group1, group2) %>%
+    select(group1, group2, everything())
 
   # clean-up for non-Bayes tests
   if (type != "bayes") {
     df %<>%
-      dplyr::mutate(p.value = stats::p.adjust(p = p.value, method = p.adjust.method)) %>%
-      dplyr::mutate(
+      mutate(p.value = stats::p.adjust(p = p.value, method = p.adjust.method)) %>%
+      mutate(
         test.details = test.details,
         p.value.adjustment = p_adjust_text(p.adjust.method)
       ) %>%
-      dplyr::rowwise() %>%
-      dplyr::mutate(
-        label = dplyr::case_when(
+      rowwise() %>%
+      mutate(
+        label = case_when(
           p.value.adjustment != "None" ~ paste0(
             "list(~italic(p)[", p.value.adjustment, "-corrected]==", format_num(p.value, k, TRUE), ")"
           ),
           TRUE ~ paste0("list(~italic(p)[uncorrected]==", format_num(p.value, k, TRUE), ")")
         )
       ) %>%
-      dplyr::ungroup()
+      ungroup()
   }
 
   # return
   as_tibble(df)
 }
+
+
+#' @title *p*-value adjustment method text
+#' @name p_adjust_text
+#'
+#' @description
+#'
+#' Preparing text to describe which *p*-value adjustment method was used
+#'
+#' @return Standardized text description for what method was used.
+#'
+#' @inheritParams pairwise_comparisons
+#'
+#' @importFrom dplyr case_when
+#'
+#' @examples
+#' library(pairwiseComparisons)
+#' p_adjust_text("none")
+#' p_adjust_text("BY")
+#' @export
+
+p_adjust_text <- function(p.adjust.method) {
+  case_when(
+    grepl("^n|^bo|^h", p.adjust.method) ~ paste0(
+      toupper(substr(p.adjust.method, 1, 1)),
+      substr(p.adjust.method, 2, nchar(p.adjust.method))
+    ),
+    grepl("^BH|^f", p.adjust.method) ~ "FDR",
+    grepl("^BY", p.adjust.method) ~ "BY",
+    TRUE ~ "Holm"
+  )
+}
+
+
+#' @name pairwise_caption
+#' @title Pairwise comparison test expression
+#'
+#' @description
+#'
+#' This returns an expression containing details about the pairwise comparison
+#' test and the *p*-value adjustment method. These details are typically
+#' included in the `ggstatsplot` package plots as a caption.
+#'
+#' @param test.description Text describing the details of the test.
+#' @param caption Additional text to be included in the plot.
+#' @param pairwise.display Decides *which* pairwise comparisons to display.
+#'   Available options are:
+#'   - `"significant"` (abbreviation accepted: `"s"`)
+#'   - `"non-significant"` (abbreviation accepted: `"ns"`)
+#'   - `"all"`
+#'
+#'   You can use this argument to make sure that your plot is not uber-cluttered
+#'   when you have multiple groups being compared and scores of pairwise
+#'   comparisons being displayed.
+#' @param ... Ignored.
+#'
+#' @importFrom dplyr case_when
+#'
+#' @examples
+#' library(pairwiseComparisons)
+#' pairwise_caption("my caption", "Student's t-test")
+#' @export
+
+pairwise_caption <- function(caption,
+                             test.description,
+                             pairwise.display = "significant",
+                             ...) {
+  # create expression
+  substitute(
+    atop(
+      displaystyle(top.text),
+      expr = paste("Pairwise test: ", bold(test), "; Comparisons shown: ", bold(display))
+    ),
+    env = list(
+      top.text = caption,
+      test = test.description,
+      display = case_when(
+        substr(pairwise.display, 1L, 1L) == "s" ~ "only significant",
+        substr(pairwise.display, 1L, 1L) == "n" ~ "only non-significant",
+        TRUE ~ "all"
+      )
+    )
+  )
+}
